@@ -27,7 +27,7 @@
 #'
 #'   Default: `RANDDT`
 #'
-#' @param unit Unit
+#' @param age_unit Age unit
 #'
 #'   The age is derived in the specified unit
 #'
@@ -35,6 +35,8 @@
 #'
 #'   Permitted Values: 'years', 'months', 'weeks', 'days', 'hours', 'minutes', 'seconds'
 #'
+#' @param unit *Deprecated*, please use `age_unit` instead.
+#'
 #' @details The age is derived as the integer part of the duration from start to
 #'   end date in the specified unit. When 'years' or 'months' are specified in the `out_unit`
 #'   parameter, because of the underlying `lubridate::time_length()` function that is used
@@ -64,12 +66,18 @@
 derive_vars_aage <- function(dataset,
                              start_date = BRTHDT,
                              end_date = RANDDT,
-                             unit = "years") {
+                             unit = "years",
+                             age_unit = "years") {
+  if (!missing(unit)) {
+    deprecate_warn("0.12.0", "derive_vars_aage(unit = )", "derive_vars_aage(age_unit = )")
+    age_unit <- unit
+  }
+
   start_date <- assert_symbol(enexpr(start_date))
   end_date <- assert_symbol(enexpr(end_date))
   assert_data_frame(dataset, required_vars = expr_c(start_date, end_date))
   assert_character_scalar(
-    unit,
+    age_unit,
     values = c("years", "months", "weeks", "days", "hours", "minutes", "seconds")
   )
 
@@ -79,7 +87,7 @@ derive_vars_aage <- function(dataset,
     new_var_unit = AAGEU,
     start_date = !!start_date,
     end_date = !!end_date,
-    out_unit = unit,
+    out_unit = age_unit,
     add_one = FALSE,
     trunc_out = TRUE
   )
