@@ -137,6 +137,7 @@ globalVariables(c(
   "ATOXGRH",
   "ATOXDSCL",
   "ATOXDSCH",
+  "FILTER",
   "GRADE_CRITERIA_CODE",
   "DIRECTION",
   "SI_UNIT_CHECK",
@@ -144,6 +145,7 @@ globalVariables(c(
   "VAR_CHECK",
   "TERM",
   "SRCVAR",
+  "TERMID",
   "TERMNAME",
   "TERM_NAME_ID",
   "TERM_UPPER",
