@@ -81,7 +81,7 @@ restrict_derivation <- function(dataset,
   assert_function(derivation, params = c("dataset"))
   assert_s3_class(args, "params", optional = TRUE)
   if (!is.null(args)) {
-    assert_function_param(deparse(substitute(derivation)), names(args))
+    assert_function(derivation, names(args))
   }
   filter <- assert_filter_cond(enexpr(filter))
 
